module.exports = defineTest({
	description:
		'await statements should never be dropped if a function has other side-effects (#1584)'
});
